package editor;

import gui.CanvasDialogue;

import java.awt.Color;
import java.awt.Desktop;
import java.awt.Dimension;
import java.awt.Window;
import java.net.URI;
import java.util.HashMap;

import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.JTextPane;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;

import utils.Global;

/**
 * Builds a dialogue window with logo images, each possibly with a web link. Such window serves as
 * the application's credits. It also takes care of other corporate imagery.
 * @author hqcasanova  
 */
final public class Credits extends CanvasDialogue {
	
	//Image files for text editor's credits
	private final static String[] CREDITS_FILES_ED = { "header_ed", "iter", "sinpromi", "portugues", "arasaac", "sarakanda", "footer" };

	//Image files for virtual keypad editor's credits
	private final static String[] CREDITS_FILES_TCV = { "header_tcv", "iter", "sinpromi", "portugues", "arasaac", "sarakanda", "footer" };

	//Links matching credit images
	private final static String[] CREDIT_LINKS = { "http://adapro.iter.es", "http://www.iter.es", "http://www.sinpromi.es", 
		                                          "http://www.azores.gov.pt/Portal/pt/entidades/srtss-iss-idsa", 
		                                          "http://catedu.es/arasaac", 
		                                          "http://www.alejandrovaldez.me/sarakanda-una-tipografia-para-ninos-y-ninas-con-dislexia/", 
		                                          "mailto:iprojects@iter.es?Subject=Adapro%20" +Global.VERSION };
	
	//Extension of credit image files 
	private final static String CREDIT_EXT = "png";
	
	//Dimensions of text area with credit images
	private final static Dimension CREDIT_DIM = new Dimension (502, 407);
	
	/**
	 * Customised constructor. Builds the HTML code and sets up the dialogue containing that code.
	 * It also resizes images and sets the dimensions of the dialogue window depending on the current
	 * resolution.
	 * @param sTitle Dialogue's title
	 * @param owner Dialogue's owner
	 * @param sFavicon Favicon's file name
	 * @param iWidth Dialogue's width 
	 * @param sSourcePath Path to credit images
	 * @param sDestPath Location for resized credit images
	 */
	public Credits (String sTitle, Window owner, String sFavicon, int iWidth, 
			        String sSourcePath, String sDestPath, String type) {
			
		//Builds the container dialogue
		super (sTitle, owner, null, null, Color.WHITE, false, JDialog.DISPOSE_ON_CLOSE, 
			   sFavicon, false);
		
		int i;
		String sHTML;
		JTextPane editCredit;
		HashMap<String,String[]> imageNames;
		
		//Initialise variables
		imageNames = new HashMap<String,String[]>();
		imageNames.put ("ed", CREDITS_FILES_ED);
		imageNames.put ("tcv", CREDITS_FILES_TCV);
		
		//Builds the HTML code
		sHTML = "<HTML><BODY>";
		for (i = 0; i < imageNames.get(type).length; i++) {
			sHTML = sHTML + "<DIV>";
			if (!CREDIT_LINKS[i].isEmpty())
			   sHTML = sHTML + "<a href=\"" +CREDIT_LINKS[i]+ "\">";
			String resourceURL = this.getClass().getResource("/corporate/" +imageNames.get(type)[i] +"."+ CREDIT_EXT).toString();
			sHTML = sHTML + "<img src=\"" +resourceURL+ "\" border=\"0\"></DIV>";
		}
		sHTML = sHTML + "</BODY></HTML>";
		
		//Loads the HTML code into the dialogue's text panel
		editCredit = new JTextPane ();
		editCredit.setContentType ("text/html;charset=UTF-8");
		editCredit.setText (sHTML);
		
		//Sets the dimensions of the text panel and makes it uneditable (so the links can be clicked)
		editCredit.setEditable (false);
		editCredit.setPreferredSize (CREDIT_DIM);
						
		//Sets up the link event listener and "attaches" it to the text panel.
		editCredit.addHyperlinkListener (new HyperlinkListener() {
		    public void hyperlinkUpdate(HyperlinkEvent e) {
		    	try {
		    	    URI target = e.getURL().toURI();
		            if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
		               if (Desktop.isDesktopSupported()) 
		        	      if (target.toString().contains ("mailto:")) { 
		        	         Desktop.getDesktop().mail (target);		        	         
		        	      } else Desktop.getDesktop().browse (target);	
		               }        
				} catch (Exception eDesk) {
					    String message = eDesk.getMessage();
					    System.out.println ("Error when opening the link: " +message); 
						eDesk.printStackTrace();
						JOptionPane.showMessageDialog (getWindow(), 
								                       message.substring(message.indexOf("Error message:") + 14), 
								                       "", 
								                       JOptionPane.ERROR_MESSAGE);
				}		        
		    }
		});

		//Adds the configured HTML-enabled text panel to the dialogue
		populate (editCredit);
	}
}
